pub struct ComponentRange {
pub(crate) name: &'static str,
pub(crate) is_conditional: bool,
}Expand description
An error type indicating that a component provided to a method was out of range, causing a failure.
Fields
name: &'static strName of the component.
is_conditional: boolWhether an input with the same value could have succeeded if the values of other components were different.
Implementations
Sourceimpl ComponentRange
impl ComponentRange
Sourcepub(crate) const fn unconditional(name: &'static str) -> Self
pub(crate) const fn unconditional(name: &'static str) -> Self
Create a new ComponentRange error that is not conditional.
Sourcepub(crate) const fn conditional(name: &'static str) -> Self
pub(crate) const fn conditional(name: &'static str) -> Self
Create a new ComponentRange error that is conditional.
Sourcepub const fn name(self) -> &'static str
pub const fn name(self) -> &'static str
Obtain the name of the component whose value was out of range.
Sourcepub const fn is_conditional(self) -> bool
pub const fn is_conditional(self) -> bool
Whether the value’s permitted range is conditional, i.e. whether an input with this value could have succeeded if the values of other components were different.
Sourceimpl ComponentRange
impl ComponentRange
Sourcepub(crate) fn into_de_error<E>(self) -> Ewhere
E: Error,
Available on crate feature serde only.
pub(crate) fn into_de_error<E>(self) -> Ewhere
E: Error,
serde only.Convert the error to a deserialization error.